@@ -109,7 +109,6 @@ var FileList={
 		if (hidden) {
 			tr.hide();
 		}
-		FileActions.display(tr.find('td.filename'));
 		return tr;
 	},
 	addDir:function(name,size,lastModified,hidden){
@@ -131,7 +130,7 @@ var FileList={
 		if (hidden) {
 			tr.hide();
 		}
-		FileActions.display(tr.find('td.filename'));
+		FileActions.display(tr.find('td.filename'), true);
 		return tr;
 	},
 	refresh:function(data) {
@@ -469,6 +468,12 @@ $(document).ready(function(){
 						data.context.attr('data-size', file.size);
 						data.context.find('td.filesize').text(humanFileSize(file.size));
 					}
+					var permissions = data.context.data('permissions');
+					if(permissions != file.permissions) {
+						data.context.attr('data-permissions', file.permissions);
+						data.context.data('permissions', file.permissions);
+					}
+					FileActions.display(data.context.find('td.filename'), true);
 					if (FileList.loadingDone) {
 						FileList.loadingDone(file.name, file.id);
 					}
